Learn R Programming

RndTexExams (version 1.0)

rte.compile.latex: Function to compile a LaTeX file

Description

This function will first check for the user's OS and then use the proper command for pdflatex compilation

Usage

rte.compile.latex(f.in, pdf.dir.out = "PdfOut")

Arguments

f.in
The location and name of latex file
pdf.dir.out
The name of the folder for the output pdf

Value

  • A flag, TRUE if the latex compilation was a sucess and FALSE if not

Examples

Run this code
f.in <- system.file("extdata", "MyRandomTest.tex", package = "RndTexExams")
pdf.dir.out <- 'PdfOut'

rte.compile.latex <- function(f.in = f.in,
                             pdf.dir.out =  pdf.dir.out)

Run the code above in your browser using DataLab